==> docker-model-1.2.0-sources.jar: annotations/io/fabric8/docker/api/model/NetworkConnectBuilder.java <==
package io.fabric8.docker.api.model;

import javax.validation.Validation;
import io.fabric8.docker.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class NetworkConnectBuilder extends NetworkConnectFluentImpl<NetworkConnectBuilder> implements VisitableBuilder<NetworkConnect,NetworkConnectBuilder>{

    NetworkConnectFluent<?> fluent;
    Boolean validationEnabled;

    public NetworkConnectBuilder(){
            this(true);
    }
    public NetworkConnectBuilder(Boolean validationEnabled){
            this(new NetworkConnect(), validationEnabled);
    }
    public NetworkConnectBuilder(NetworkConnectFluent<?> fluent){
            this(fluent, true);
    }
    public NetworkConnectBuilder(NetworkConnectFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new NetworkConnect(), validationEnabled);
    }
    public NetworkConnectBuilder(NetworkConnectFluent<?> fluent,NetworkConnect instance){
            this(fluent, instance, true);
    }
    public NetworkConnectBuilder(NetworkConnectFluent<?> fluent,NetworkConnect instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withContainer(instance.getContainer()); 
            this.validationEnabled = validationEnabled; 
    }
    public NetworkConnectBuilder(NetworkConnect instance){
            this(instance,true);
    }
    public NetworkConnectBuilder(NetworkConnect instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withContainer(instance.getContainer()); 
            this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.docker.api.model.EditableNetworkConnect build(){
            EditableNetworkConnect buildable = new EditableNetworkConnect(fluent.getContainer());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            NetworkConnectBuilder that = (NetworkConnectBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> docker-model-1.2.2-sources.jar: annotations/io/fabric8/docker/api/model/NetworkConnectBuilder.java <==
package io.fabric8.docker.api.model;

import io.fabric8.docker.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class NetworkConnectBuilder extends NetworkConnectFluentImpl<NetworkConnectBuilder> implements VisitableBuilder<NetworkConnect,NetworkConnectBuilder>{

    NetworkConnectFluent<?> fluent;
    Boolean validationEnabled;

    public NetworkConnectBuilder(){
            this(true);
    }
    public NetworkConnectBuilder(Boolean validationEnabled){
            this(new NetworkConnect(), validationEnabled);
    }
    public NetworkConnectBuilder(NetworkConnectFluent<?> fluent){
            this(fluent, true);
    }
    public NetworkConnectBuilder(NetworkConnectFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new NetworkConnect(), validationEnabled);
    }
    public NetworkConnectBuilder(NetworkConnectFluent<?> fluent,NetworkConnect instance){
            this(fluent, instance, true);
    }
    public NetworkConnectBuilder(NetworkConnectFluent<?> fluent,NetworkConnect instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withContainer(instance.getContainer()); 
            this.validationEnabled = validationEnabled; 
    }
    public NetworkConnectBuilder(NetworkConnect instance){
            this(instance,true);
    }
    public NetworkConnectBuilder(NetworkConnect instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withContainer(instance.getContainer()); 
            this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.docker.api.model.EditableNetworkConnect build(){
            EditableNetworkConnect buildable = new EditableNetworkConnect(fluent.getContainer());
            io.fabric8.docker.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            NetworkConnectBuilder that = (NetworkConnectBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
